# deneb

`deneb` is a visualization library build on top of Altair and Vega. It allows simple creation of chart types such as pairplots, facted line plots, and correlation matrices. 


## Installation

```commandline
$ pip install deneb
```


## Usage

See notebooks in `examples/`.

![](https://raw.githubusercontent.com/jan-matthis/deneb/main/examples/pairplot.png)


## License

MIT
